@@ -1,6 +1,6 @@
 /*
  * xinstall.c
- * $Id: xinstall.c 57602 2009-09-14 01:22:38Z raimue@macports.org $
+ * $Id: xinstall.c 120070 2014-05-14 22:27:37Z cal@macports.org $
  * Copyright (c) 1987, 1993
  *	The Regents of the University of California.  All rights reserved.
  *
@@ -41,6 +41,9 @@
 #include <config.h>
 #endif
 
+/* required for u_int and u_long */
+#define _BSD_SOURCE
+
 #if HAVE_SYS_CDEFS_H
 #include <sys/cdefs.h>
 #endif
@@ -104,9 +107,8 @@ extern int copyfile(const char *from, const char *to, void *state,
 #define ALLPERMS (S_ISUID|S_ISGID|S_ISTXT|S_IRWXU|S_IRWXG|S_IRWXO)
 #endif
 
-#if !HAVE_SETMODE
-void * setmode(const char *mode_str); 
-mode_t getmode(const void *set, mode_t mode);
+#ifndef HAVE_SETMODE
+#include "setmode.h"
 #endif
 
 /* Bootstrap aid - this doesn't exist in most older releases */
@@ -146,10 +148,10 @@ InstallCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_Obj *
 {
 	struct stat from_sb, to_sb;
 	mode_t *set;
-	u_long fset;
+	u_long fset = 0;
 	int no_target, rval;
 	u_int iflags;
-	char *flags, *curdir;
+	char *curdir;
 	const char *group, *owner, *cp;
 	Tcl_Obj *to_name;
 	int dodir = 0;
@@ -199,7 +201,7 @@ InstallCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_Obj *
 				Tcl_WrongNumArgs(interp, 1, objv, "-f");
 				return TCL_ERROR;
 			}
-			flags = Tcl_GetString(*(++objv));
+			char *flags = Tcl_GetString(*(++objv));
 			if (strtofflags(&flags, &fset, NULL)) {
 				Tcl_SetResult(interp, "invalid flags for -f", TCL_STATIC);
 				return TCL_ERROR;
@@ -429,7 +431,11 @@ numeric_id(Tcl_Interp *interp, const char *name, const char *type, int *rval)
  *	build a path name and install the file
  */
 static int
+#if defined(UF_NODUMP)
 install(Tcl_Interp *interp, const char *from_name, const char *to_name, u_long fset, u_int flags)
+#else
+install(Tcl_Interp *interp, const char *from_name, const char *to_name, u_long fset UNUSED, u_int flags)
+#endif
 {
 	struct stat from_sb, temp_sb, to_sb;
 	struct timeval tvb[2];
@@ -870,7 +876,11 @@ create_tempfile(const char *path, char *temp, size_t tsize)
  *	create a new file, overwriting an existing one if necessary
  */
 static int
+#if defined(UF_IMMUTABLE) && defined(SF_IMMUTABLE)
 create_newfile(Tcl_Interp *interp, const char *path, int target, struct stat *sbp)
+#else
+create_newfile(Tcl_Interp *interp, const char *path, int target, struct stat *sbp UNUSED)
+#endif
 {
 	char backup[MAXPATHLEN];
 	int saved_errno = 0;
@@ -1026,6 +1036,7 @@ strip(const char *to_name)
 		if (wait(&status) == -1 || status) {
 			serrno = errno;
 			(void)unlink(to_name);
+			errno = serrno;
 			return;
 		}
 	}
@@ -1105,7 +1116,11 @@ usage(Tcl_Interp *interp)
  *	return true (1) if mmap should be tried, false (0) if not.
  */
 int
+#ifdef MFSNAMELEN
 trymmap(int fd)
+#else
+trymmap(int fd UNUSED)
+#endif
 {
 /*
  * The ifdef is for bootstrapping - f_fstypename doesn't exist in
