@@ -1,7 +1,7 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=tcl:et:sw=4:ts=4:sts=4
-# $Id: portconfigure.tcl 109893 2013-08-21 14:37:40Z larryv@macports.org $
+# $Id: portconfigure.tcl 121317 2014-06-23 10:11:51Z jmr@macports.org $
 #
-# Copyright (c) 2007 - 2013 The MacPorts Project
+# Copyright (c) 2007 - 2014 The MacPorts Project
 # Copyright (c) 2007 Markus W. Weissmann <mww@macports.org>
 # Copyright (c) 2002 - 2003 Apple Inc.
 # All rights reserved.
@@ -51,9 +51,11 @@ default configure.cmd       ./configure
 default configure.nice      {${buildnicevalue}}
 default configure.dir       {${worksrcpath}}
 default autoreconf.dir      {${worksrcpath}}
-default autoreconf.pre_args {--install}
+default autoreconf.args     {{--install --verbose}}
 default autoconf.dir        {${worksrcpath}}
+default autoconf.args       {--verbose}
 default automake.dir        {${worksrcpath}}
+default automake.args       {--verbose}
 default xmkmf.cmd           xmkmf
 default xmkmf.dir           {${worksrcpath}}
 default use_configure       yes
@@ -74,10 +76,10 @@ proc portconfigure::add_build_dep { type dep } {
     global ${type}.cmd option_defaults
 
     if {![info exists ${type}.cmd] || (
-        ([info exists option_defaults(${type}.cmd)] && [set ${type}.cmd] == $option_defaults(${type}.cmd)) ||
-        (![info exists option_defaults(${type}.cmd)] && [set ${type}.cmd] == "${type}")
+        ([info exists option_defaults(${type}.cmd)] && [set ${type}.cmd] eq $option_defaults(${type}.cmd)) ||
+        (![info exists option_defaults(${type}.cmd)] && [set ${type}.cmd] eq ${type})
         )} {
-            eval depends_build-append $dep
+            eval [linsert $dep 0 depends_build-append]
     }
 }
 
@@ -92,19 +94,19 @@ proc portconfigure::set_configure_type {option action args} {
         xmkmf       port:imake
     }
 
-    if {[string equal ${action} "set"]} {
+    if {$action eq "set"} {
         switch $option {
             autoreconf.cmd  -
             automake.cmd    -
             autoconf.cmd {
-                eval depends_build-delete $configure_map(autoconf)
+                eval [linsert $configure_map(autoconf) 0 depends_build-delete]
             }
             xmkmf.cmd {
-                depends_build-delete $configure_map(xmkmf)
+                eval [linsert $configure_map(xmkmf) 0 depends_build-delete]
             }
             use_xmkmf {
                 if {[tbool args]} {
-                    depends_build-append $configure_map(xmkmf)
+                    eval [linsert $configure_map(xmkmf) 0 depends_build-append]
                 }
             }
             default {
@@ -160,10 +162,12 @@ default configure.bison             {}
 default configure.pkg_config        {}
 default configure.pkg_config_path   {}
 
-options configure.build_arch configure.ld_archflags configure.sdkroot
+options configure.build_arch configure.ld_archflags \
+        configure.sdk_version configure.sdkroot
 default configure.build_arch    {[portconfigure::choose_supported_archs ${build_arch}]}
 default configure.ld_archflags  {[portconfigure::configure_get_ld_archflags]}
-default configure.sdkroot       {[portconfigure::configure_get_sdkroot]}
+default configure.sdk_version   {$macosx_sdk_version}
+default configure.sdkroot       {[portconfigure::configure_get_sdkroot ${configure.sdk_version}]}
 foreach tool {cc cxx objc objcxx f77 f90 fc} {
     options configure.${tool}_archflags
     default configure.${tool}_archflags  "\[portconfigure::configure_get_archflags $tool\]"
@@ -190,20 +194,18 @@ options configure.ccache configure.distcc configure.pipe configure.cc \
 default configure.ccache        {${configureccache}}
 default configure.distcc        {${configuredistcc}}
 default configure.pipe          {${configurepipe}}
-default configure.cc            {[portconfigure::configure_get_compiler cc]}
-default configure.cxx           {[portconfigure::configure_get_compiler cxx]}
-default configure.cpp           {[portconfigure::configure_get_compiler cpp]}
-default configure.objc          {[portconfigure::configure_get_compiler objc]}
-default configure.objcxx        {[portconfigure::configure_get_compiler objcxx]}
-default configure.f77           {[portconfigure::configure_get_compiler f77]}
-default configure.f90           {[portconfigure::configure_get_compiler f90]}
-default configure.fc            {[portconfigure::configure_get_compiler fc]}
-default configure.javac         {[portconfigure::configure_get_compiler javac]}
+foreach tool {cc cxx objc objcxx cpp f77 f90 fc javac} {
+    default configure.$tool     "\[portconfigure::configure_get_compiler $tool\]"
+}
 default configure.compiler      {[portconfigure::configure_get_default_compiler]}
 default compiler.fallback       {[portconfigure::get_compiler_fallback]}
 default compiler.blacklist      {}
 default compiler.whitelist      {}
 
+# Select a C++ STL implementation
+options configure.cxx_stdlib
+default configure.cxx_stdlib    {$cxx_stdlib}
+
 set_ui_prefix
 
 proc portconfigure::configure_start {args} {
@@ -229,7 +231,7 @@ proc portconfigure::configure_start {args} {
         {^macports-llvm-gcc-4\.2$}          {MacPorts LLVM-GCC 4.2}
     }
     foreach {re fmt} $valid_compilers {
-        if {[set matches [regexp -inline $re $compiler]] ne {}} {
+        if {[set matches [regexp -inline $re $compiler]] ne ""} {
             set compiler_name [eval [linsert [lrange $matches 1 end] 0 format $fmt]]
             break
         }
@@ -244,10 +246,10 @@ proc portconfigure::configure_start {args} {
     if {${configure.ccache}} {
         # Create ccache directory with correct permissions with root privileges
         elevateToRoot "configure ccache"
-        if [catch {
+        if {[catch {
                 file mkdir ${ccache_dir}
                 file attributes ${ccache_dir} -owner ${macportsuser} -permissions 0755
-            } result] {
+            } result]} {
             ui_warn "ccache_dir ${ccache_dir} could not be created; disabling ccache: $result"
             set configure.ccache no
         }
@@ -255,9 +257,9 @@ proc portconfigure::configure_start {args} {
 
         # Initialize ccache directory with the given maximum size
         if {${configure.ccache}} {
-            if [catch {
+            if {[catch {
                 exec ccache -M ${ccache_size} >/dev/null
-            } result] {
+            } result]} {
                 ui_warn "ccache_dir ${ccache_dir} could not be initialized; disabling ccache: $result"
                 set configure.ccache no
             }
@@ -270,16 +272,16 @@ proc portconfigure::configure_start {args} {
 # universal_archs
 proc portconfigure::choose_supported_archs {archs} {
     global supported_archs
-    if {$supported_archs == ""} {
+    if {$supported_archs eq ""} {
         return $archs
     }
     set ret {}
     foreach arch $archs {
         if {[lsearch -exact $supported_archs $arch] != -1} {
             set add_arch $arch
-        } elseif {$arch == "x86_64" && [lsearch -exact $supported_archs "i386"] != -1} {
+        } elseif {$arch eq "x86_64" && [lsearch -exact $supported_archs "i386"] != -1} {
             set add_arch "i386"
-        } elseif {$arch == "ppc64" && [lsearch -exact $supported_archs "ppc"] != -1} {
+        } elseif {$arch eq "ppc64" && [lsearch -exact $supported_archs "ppc"] != -1} {
             set add_arch "ppc"
         } else {
             continue
@@ -299,14 +301,14 @@ proc portconfigure::configure_get_archflags {tool} {
         set flags "-m64"
     } elseif {[tbool configure.m32]} {
         set flags "-m32"
-    } elseif {${configure.build_arch} != ""} {
+    } elseif {${configure.build_arch} ne ""} {
         if {[arch_flag_supported ${configure.compiler}] &&
             [regexp {^(?:cc|cxx|objc|objcxx)$} $tool]
         } then {
             set flags "-arch ${configure.build_arch}"
-        } elseif {${configure.build_arch} == "x86_64" || ${configure.build_arch} == "ppc64"} {
+        } elseif {${configure.build_arch} eq "x86_64" || ${configure.build_arch} eq "ppc64"} {
             set flags "-m64"
-        } elseif {${configure.compiler} != "gcc-3.3"} {
+        } elseif {${configure.compiler} ne "gcc-3.3"} {
             set flags "-m32"
         }
     }
@@ -319,32 +321,32 @@ proc portconfigure::configure_get_archflags {tool} {
 # ld directly. So we punt and let portfiles deal with that case.
 proc portconfigure::configure_get_ld_archflags {args} {
     global configure.build_arch configure.compiler
-    if {${configure.build_arch} != "" && [arch_flag_supported ${configure.compiler}]} {
+    if {${configure.build_arch} ne "" && [arch_flag_supported ${configure.compiler}]} {
         return "-arch ${configure.build_arch}"
     } else {
         return ""
     }
 }
 
-proc portconfigure::configure_get_sdkroot {} {
-    global developer_dir macosx_deployment_target macosx_version xcodeversion os.arch os.platform
-    if {${os.platform} == "darwin" && ($macosx_deployment_target != $macosx_version
-        || (${os.arch} == "powerpc" && $macosx_version == "10.4" && [variant_exists universal] && [variant_isset universal]))} {
+proc portconfigure::configure_get_sdkroot {sdk_version} {
+    global developer_dir macosx_version xcodeversion os.arch os.platform
+    if {${os.platform} eq "darwin" && ($sdk_version ne $macosx_version
+        || (${os.arch} eq "powerpc" && $macosx_version eq "10.4" && [variant_exists universal] && [variant_isset universal]))} {
         if {[vercmp $xcodeversion 4.3] < 0} {
-            set sdks_dir "${developer_dir}/SDKs"
+            set sdks_dir ${developer_dir}/SDKs
         } else {
-            set sdks_dir "${developer_dir}/Platforms/MacOSX.platform/Developer/SDKs"
+            set sdks_dir ${developer_dir}/Platforms/MacOSX.platform/Developer/SDKs
         }
-        if {$macosx_deployment_target == "10.4"} {
-            set sdk "${sdks_dir}/MacOSX10.4u.sdk"
+        if {$sdk_version eq "10.4"} {
+            set sdk ${sdks_dir}/MacOSX10.4u.sdk
         } else {
-            set sdk "${sdks_dir}/MacOSX${macosx_deployment_target}.sdk"
+            set sdk ${sdks_dir}/MacOSX${sdk_version}.sdk
         }
         if {[file exists $sdk]} {
             return $sdk
         }
     }
-    return ""
+    return {}
 }
 
 # internal function to determine the "-arch xy" flags for the compiler
@@ -352,7 +354,7 @@ proc portconfigure::configure_get_universal_archflags {args} {
     global configure.universal_archs
     set flags ""
     foreach arch ${configure.universal_archs} {
-        if {$flags == ""} {
+        if {$flags eq ""} {
             set flags "-arch $arch"
         } else {
             append flags " -arch $arch"
@@ -376,42 +378,15 @@ proc portconfigure::arch_flag_supported {compiler} {
     return [regexp {^gcc-4|llvm|apple|clang} $compiler]
 }
 
-# maps compiler names to the port that provides them
-# TODO: Remove this after 2.2 is released and ports aren't referring to it.
-array set portconfigure::compiler_name_map {
-        apple-gcc-4.0           apple-gcc40
-        apple-gcc-4.2           apple-gcc42
-        macports-gcc-4.2        gcc42
-        macports-gcc-4.3        gcc43
-        macports-gcc-4.4        gcc44
-        macports-gcc-4.5        gcc45
-        macports-gcc-4.6        gcc46
-        macports-gcc-4.7        gcc47
-        macports-gcc-4.8        gcc48
-        macports-llvm-gcc-4.2   llvm-gcc42
-        macports-clang-2.9      clang-2.9
-        macports-clang-3.0      clang-3.0
-        macports-clang-3.1      clang-3.1
-        macports-clang-3.2      clang-3.2
-        macports-clang-3.3      clang-3.3
-        macports-dragonegg-3.0  dragonegg-3.0
-        macports-dragonegg-3.1  dragonegg-3.1
-        macports-dragonegg-3.2  dragonegg-3.2
-        macports-dragonegg-3.3  dragonegg-3.3
-}
-
-# Mapping from compiler names to compiler ports, for private use by
-# compiler_port_name. Do not access directly.
-set portconfigure::valid_compiler_ports {
-    {^apple-gcc-(\d+)\.(\d+)$}                          {apple-gcc%s%s}
-    {^macports-clang-(\d+\.\d+)$}                       {clang-%s}
-    {^macports-dragonegg-(\d+\.\d+)(-gcc-\d+\.\d+)?$}   {dragonegg-%s%s}
-    {^macports-(llvm-)?gcc-(\d+)\.(\d+)$}               {%sgcc%s%s}
-}
-
 proc portconfigure::compiler_port_name {compiler} {
-    foreach {re fmt} $portconfigure::valid_compiler_ports {
-        if {[set matches [regexp -inline $re $compiler]] ne {}} {
+    set valid_compiler_ports {
+        {^apple-gcc-(\d+)\.(\d+)$}                          {apple-gcc%s%s}
+        {^macports-clang-(\d+\.\d+)$}                       {clang-%s}
+        {^macports-dragonegg-(\d+\.\d+)(-gcc-\d+\.\d+)?$}   {dragonegg-%s%s}
+        {^macports-(llvm-)?gcc-(\d+)\.(\d+)$}               {%sgcc%s%s}
+    }
+    foreach {re fmt} $valid_compiler_ports {
+        if {[set matches [regexp -inline $re $compiler]] ne ""} {
             return [eval [linsert [lrange $matches 1 end] 0 format $fmt]]
         }
     }
@@ -419,12 +394,12 @@ proc portconfigure::compiler_port_name {compiler} {
 }
 
 proc portconfigure::compiler_is_port {compiler} {
-    return [expr {[portconfigure::compiler_port_name ${compiler}] != ""}]
+    return [expr {[portconfigure::compiler_port_name ${compiler}] ne ""}]
 }
 
 # internal function to determine the default compiler
 proc portconfigure::configure_get_default_compiler {args} {
-    if {[option compiler.whitelist] != {}} {
+    if {[option compiler.whitelist] ne ""} {
         set search_list [option compiler.whitelist]
     } else {
         set search_list [option compiler.fallback]
@@ -450,29 +425,29 @@ proc portconfigure::configure_get_default_compiler {args} {
 
 # internal function to choose compiler fallback list based on platform
 proc portconfigure::get_compiler_fallback {} {
-    global xcodeversion macosx_deployment_target default_compilers
+    global xcodeversion macosx_deployment_target default_compilers configure.sdkroot
     if {[info exists default_compilers]} {
         return $default_compilers
-    } elseif {$xcodeversion == "none" || $xcodeversion == ""} {
+    } elseif {$xcodeversion eq "none" || $xcodeversion eq ""} {
         return {cc}
-    } elseif {[vercmp $xcodeversion 4.7] >= 0} {
-        return {clang macports-llvm-gcc-4.2 apple-gcc-4.2 macports-clang-3.3}
-    } elseif {[vercmp $xcodeversion 4.2] >= 0} {
-        return {clang llvm-gcc-4.2 apple-gcc-4.2 macports-clang-3.3}
+    } elseif {[vercmp $xcodeversion 6.0] >= 0 && [vercmp $macosx_deployment_target 10.10] >= 0} {
+        return {clang macports-clang-3.4 macports-clang-3.3}
+    } elseif {[vercmp $xcodeversion 5.0] >= 0} {
+        return {clang macports-clang-3.4 macports-clang-3.3 macports-llvm-gcc-4.2 apple-gcc-4.2}
+    } elseif {[vercmp $xcodeversion 4.3] >= 0} {
+        return {clang llvm-gcc-4.2 macports-clang-3.4 macports-clang-3.3 apple-gcc-4.2}
     } elseif {[vercmp $xcodeversion 4.0] >= 0} {
-        return {llvm-gcc-4.2 clang gcc-4.2 macports-clang-3.3 apple-gcc-4.2}
+        return {llvm-gcc-4.2 clang gcc-4.2 macports-clang-3.4 macports-clang-3.3 apple-gcc-4.2}
     } elseif {[vercmp $xcodeversion 3.2] >= 0} {
-        if {$macosx_deployment_target == "10.4"} {
-            # It's not the deployment target that is the issue, it's the
-            # 10.4u SDK which base chooses if the deployment_target is set
+        if {[string match *10.4u* ${configure.sdkroot}]} {
             return {gcc-4.0}
         } else {
-            return {gcc-4.2 clang llvm-gcc-4.2 macports-clang-3.3 macports-llvm-gcc-4.2 apple-gcc-4.2 gcc-4.0}
+            return {gcc-4.2 clang llvm-gcc-4.2 macports-clang-3.4 macports-clang-3.3 macports-llvm-gcc-4.2 apple-gcc-4.2 gcc-4.0}
         }
     } elseif {[vercmp $xcodeversion 3.0] >= 0} {
-        return {gcc-4.2 apple-gcc-4.2 gcc-4.0 macports-clang-3.3}
+        return {gcc-4.2 apple-gcc-4.2 gcc-4.0 macports-clang-3.4 macports-clang-3.3}
     } else {
-        return {gcc-4.0 apple-gcc-4.2 gcc-3.3 macports-clang-3.3}
+        return {apple-gcc-4.2 gcc-4.0 gcc-3.3 macports-clang-3.3}
     }
 }
 
@@ -503,7 +478,7 @@ proc portconfigure::find_developer_tool {name} {
 # internal function to find correct compilers
 proc portconfigure::configure_get_compiler {type {compiler {}}} {
     global configure.compiler prefix
-    if {$compiler == {}} {
+    if {$compiler eq ""} {
         set compiler ${configure.compiler}
     }
     # Tcl 8.4's switch doesn't support -matchvar.
@@ -513,7 +488,7 @@ proc portconfigure::configure_get_compiler {type {compiler {}}} {
             objc    { return ${prefix}/bin/gcc-apple${suffix} }
             cxx     -
             objcxx  {
-                if {$suffix == "-4.2"} {
+                if {$suffix eq "-4.2"} {
                     return ${prefix}/bin/g++-apple${suffix}
                 }
             }
@@ -549,7 +524,7 @@ proc portconfigure::configure_get_compiler {type {compiler {}}} {
             cpp     { return [find_developer_tool llvm-cpp-4.2] }
         }
     } elseif {[regexp {^macports-clang(-\d+\.\d+)?$} $compiler -> suffix]} {
-        if {$suffix ne {}} {
+        if {$suffix ne ""} {
             set suffix "-mp${suffix}"
         }
         switch $type {
@@ -560,7 +535,7 @@ proc portconfigure::configure_get_compiler {type {compiler {}}} {
         }
     } elseif {[regexp {^macports-dragonegg(-\d+\.\d+)(?:-gcc(-\d+\.\d+))?$} $compiler \
                 -> infix suffix]} {
-        if {$suffix ne {}} {
+        if {$suffix ne ""} {
             set suffix "-mp${suffix}"
         }
         switch $type {
@@ -574,7 +549,7 @@ proc portconfigure::configure_get_compiler {type {compiler {}}} {
             f90     { return ${prefix}/bin/dragonegg${infix}-gfortran${suffix} }
         }
     } elseif {[regexp {^macports-gcc(-\d+\.\d+)?$} $compiler -> suffix]} {
-        if {$suffix ne {}} {
+        if {$suffix ne ""} {
             set suffix "-mp${suffix}"
         }
         switch $type {
@@ -653,7 +628,7 @@ proc portconfigure::configure_main {args} {
            configure.perl configure.python configure.ruby configure.install configure.awk configure.bison \
            configure.pkg_config configure.pkg_config_path \
            configure.ccache configure.distcc configure.cpp configure.javac configure.sdkroot \
-           configure.march configure.mtune \
+           configure.march configure.mtune configure.cxx_stdlib \
            os.platform os.major
     foreach tool {cc cxx objc objcxx f77 f90 fc ld} {
         global configure.${tool} configure.${tool}_archflags
@@ -682,13 +657,13 @@ proc portconfigure::configure_main {args} {
 
     if {[tbool use_xmkmf]} {
         parse_environment xmkmf
-        append_list_to_environment_value xmkmf "IMAKECPP" ${configure.cpp}
+        append_to_environment_value xmkmf "IMAKECPP" ${configure.cpp}
         if {[catch {command_exec xmkmf} result]} {
             return -code error "[format [msgcat::mc "%s failure: %s"] xmkmf $result]"
         }
 
         parse_environment xmkmf
-        append_list_to_environment_value xmkmf "IMAKECPP" ${configure.cpp}
+        append_to_environment_value xmkmf "IMAKECPP" ${configure.cpp}
         if {[catch {command_exec "cd ${worksrcpath} && make Makefiles" -varprefix xmkmf} result]} {
             return -code error "[format [msgcat::mc "%s failure: %s"] "make Makefiles" $result]"
         }
@@ -698,86 +673,81 @@ proc portconfigure::configure_main {args} {
 
         # Set pre-compiler filter to use (ccache/distcc), if any.
         if {[tbool configure.ccache] && [tbool configure.distcc]} {
-            set filter "ccache "
-            append_list_to_environment_value configure "CCACHE_PREFIX" "distcc"
+            set filter ccache
+            append_to_environment_value configure "CCACHE_PREFIX" "distcc"
         } elseif {[tbool configure.ccache]} {
-            set filter "ccache "
+            set filter ccache
         } elseif {[tbool configure.distcc]} {
-            set filter "distcc "
+            set filter distcc
         } else {
             set filter ""
         }
-        
+        foreach env_var {CC CXX OBJC OBJCXX} {
+            append_to_environment_value configure $env_var $filter
+        }
+
         # Set flags controlling the kind of compiler output.
         if {[tbool configure.pipe]} {
-            set output "-pipe "
+            set output -pipe
         } else {
             set output ""
         }
+        foreach env_var {CFLAGS CXXFLAGS OBJCFLAGS OBJCXXFLAGS FFLAGS F90FLAGS FCFLAGS} {
+            append_to_environment_value configure $env_var $output
+        }
 
         # Append configure flags.
-        append_list_to_environment_value configure "CC" ${filter}${configure.cc}
-        append_list_to_environment_value configure "CXX" ${filter}${configure.cxx}
-        append_list_to_environment_value configure "OBJC" ${filter}${configure.objc}
-        append_list_to_environment_value configure "OBJCXX" ${filter}${configure.objcxx}
-        append_list_to_environment_value configure "FC" ${configure.fc}
-        append_list_to_environment_value configure "F77" ${configure.f77}
-        append_list_to_environment_value configure "F90" ${configure.f90}
-        append_list_to_environment_value configure "JAVAC" ${configure.javac}
-        append_list_to_environment_value configure "CFLAGS" ${output}${configure.cflags}
-        append_list_to_environment_value configure "CPPFLAGS" ${configure.cppflags}
-        append_list_to_environment_value configure "CXXFLAGS" ${output}${configure.cxxflags}
-        append_list_to_environment_value configure "OBJCFLAGS" ${output}${configure.objcflags}
-        append_list_to_environment_value configure "OBJCXXFLAGS" ${output}${configure.objcxxflags}
-        append_list_to_environment_value configure "LDFLAGS" ${configure.ldflags}
-        append_list_to_environment_value configure "LIBS" ${configure.libs}
-        append_list_to_environment_value configure "FFLAGS" ${output}${configure.fflags}
-        append_list_to_environment_value configure "F90FLAGS" ${output}${configure.f90flags}
-        append_list_to_environment_value configure "FCFLAGS" ${output}${configure.fcflags}
-        append_list_to_environment_value configure "CLASSPATH" ${configure.classpath}
-        append_list_to_environment_value configure "PERL" ${configure.perl}
-        append_list_to_environment_value configure "PYTHON" ${configure.python}
-        append_list_to_environment_value configure "RUBY" ${configure.ruby}
-        append_list_to_environment_value configure "INSTALL" ${configure.install}
-        append_list_to_environment_value configure "AWK" ${configure.awk}
-        append_list_to_environment_value configure "BISON" ${configure.bison}
-        append_list_to_environment_value configure "PKG_CONFIG" ${configure.pkg_config}
-        append_list_to_environment_value configure "PKG_CONFIG_PATH" ${configure.pkg_config_path}
+        foreach env_var { \
+            CC CXX OBJC OBJCXX FC F77 F90 JAVAC \
+            CFLAGS CPPFLAGS CXXFLAGS OBJCFLAGS OBJCXXFLAGS \
+            FFLAGS F90FLAGS FCFLAGS LDFLAGS LIBS CLASSPATH \
+            PERL PYTHON RUBY INSTALL AWK BISON PKG_CONFIG PKG_CONFIG_PATH \
+        } {
+            set value [option configure.[string tolower $env_var]]
+            eval [linsert $value 0 append_to_environment_value configure $env_var]
+        }
 
         # https://trac.macports.org/ticket/34221
-        if {${os.platform} == "darwin" && ${os.major} == 12} {
-            append_list_to_environment_value configure "__CFPREFERENCES_AVOID_DAEMON" 1
+        if {${os.platform} eq "darwin" && ${os.major} == 12} {
+            append_to_environment_value configure "__CFPREFERENCES_AVOID_DAEMON" 1
         }
 
         # add SDK flags if cross-compiling (or universal on ppc tiger)
-        if {${configure.sdkroot} != ""} {
-            foreach flags {CPPFLAGS CFLAGS CXXFLAGS OBJCFLAGS OBJCXXFLAGS} {
-                append_list_to_environment_value configure $flags "-isysroot ${configure.sdkroot}"
+        if {${configure.sdkroot} ne ""} {
+            foreach env_var {CPPFLAGS CFLAGS CXXFLAGS OBJCFLAGS OBJCXXFLAGS} {
+                append_to_environment_value configure $env_var -isysroot ${configure.sdkroot}
             }
-            append_list_to_environment_value configure "LDFLAGS" "-Wl,-syslibroot,${configure.sdkroot}"
+            append_to_environment_value configure "LDFLAGS" -Wl,-syslibroot,${configure.sdkroot}
         }
 
         # add extra flags that are conditional on whether we're building universal
+        eval [linsert [get_canonical_archflags cc] 0 append_to_environment_value configure CFLAGS]
+        foreach tool {cxx objc objcxx cpp f77 f90 fc ld} {
+            if {[catch {get_canonical_archflags $tool} flags]} {
+                continue
+            }
+            set env_var [string toupper $tool]FLAGS
+            eval [linsert $flags 0 append_to_environment_value configure $env_var]
+        }
         if {[variant_exists universal] && [variant_isset universal]} {
-            append_list_to_environment_value configure "CFLAGS" ${configure.universal_cflags}
-            append_list_to_environment_value configure "CXXFLAGS" ${configure.universal_cxxflags}
-            append_list_to_environment_value configure "OBJCFLAGS" ${configure.universal_objcflags}
-            append_list_to_environment_value configure "OBJCXXFLAGS" ${configure.universal_objcxxflags}
-            append_list_to_environment_value configure "CPPFLAGS" ${configure.universal_cppflags}
-            append_list_to_environment_value configure "LDFLAGS" ${configure.universal_ldflags}
-            eval configure.pre_args-append ${configure.universal_args}
+            eval [linsert ${configure.universal_args} 0 configure.pre_args-append]
         } else {
-            foreach {tool flags} {cc CFLAGS cxx CXXFLAGS objc OBJCFLAGS objcxx OBJCXXFLAGS f77 FFLAGS f90 F90FLAGS fc FCFLAGS ld LDFLAGS} {
-                append_list_to_environment_value configure $flags [set configure.${tool}_archflags]
-                if {${configure.march} != {}} {
-                    append_list_to_environment_value configure $flags "-march=${configure.march}"
+            foreach env_var {CFLAGS CXXFLAGS OBJCFLAGS OBJCXXFLAGS FFLAGS F90FLAGS FCFLAGS LDFLAGS} {
+                if {${configure.march} ne ""} {
+                    append_to_environment_value configure $env_var -march=${configure.march}
                 }
-                if {${configure.mtune} != {}} {
-                    append_list_to_environment_value configure $flags "-mtune=${configure.mtune}"
+                if {${configure.mtune} ne ""} {
+                    append_to_environment_value configure $env_var -mtune=${configure.mtune}
                 }
             }
         }
 
+        # Add flags to specify C++ STL implementation
+        if {${configure.cxx_stdlib} ne "" && [string match "*clang*" [option configure.cxx]]} {
+            append_to_environment_value configure CXXFLAGS -stdlib=${configure.cxx_stdlib}
+            append_to_environment_value configure OBJCXXFLAGS -stdlib=${configure.cxx_stdlib}
+        }
+
         # Execute the command (with the new environment).
         if {[catch {command_exec configure} result]} {
             global configure.dir
